# corenetworks

[![Build Status](https://img.shields.io/drone/build/xoxys/corenetworks?logo=drone)](https://cloud.drone.io/xoxys/corenetworks)
[![Python Version](https://img.shields.io/pypi/pyversions/corenetworks.svg)](https://pypi.org/project/corenetworks/)
[![PyPi Status](https://img.shields.io/pypi/status/corenetworks.svg)](https://pypi.org/project/corenetworks/)
[![PyPi Release](https://img.shields.io/pypi/v/corenetworks.svg)](https://pypi.org/project/corenetworks/)
[![Codecov](https://img.shields.io/codecov/c/github/xoxys/corenetworks)](https://codecov.io/gh/xoxys/corenetworks)
[![License: MIT](https://img.shields.io/github/license/xoxys/corenetworks)](LICENSE)

Python library for the [https://core-networks.de](https://beta.api.core-networks.de/doc/) DNS API.

You can find the full documentation at [https://corenetworks.geekdocs.de](https://corenetworks.geekdocs.de/).

## License

This project is licensed under the Apache License 2.0 - see the [LICENSE](LICENSE) file for details.

## Maintainers and Contributors

[Robert Kaussow](https://github.com/xoxys)
